import { lazy, Suspense } from 'react';
import { BrowserRouter, Switch } from 'react-router-dom';
import 'react-toastify/dist/ReactToastify.css';
import { ToastContainer } from 'react-toastify';

import Loader from './components/Loader/Loader';
import Navigation from './components/Navigation/Navigation';
import PrivateRoute from './components/Routes/PrivateRoute/PrivateRoute';
import PublicRoute from './components/Routes/PublicRoute/PublicRoute';

const Categories = lazy(() =>
  import(
    './components/Categories/Categories' /* webpackChunkName: "CategoriesPage" */
  ),
);

const DetailCategory = lazy(() =>
  import(
    './components/Categories/DetailCategory/DetailCategory' /* webpackChunkName: "DetailCategory" */
  ),
);

const Goods = lazy(() =>
  import('./components/Goods/Goods' /* webpackChunkName: "GoodsPage" */),
);

const DetailGood = lazy(() =>
  import(
    './components/Goods/DetailGood/DetailGood' /* webpackChunkName: "DetailGood" */
  ),
);

const Orders = lazy(() =>
  import('./components/Orders/Orders' /* webpackChunkName: "OrdersPage" */),
);

const DetailOrder = lazy(() =>
  import(
    './components/Orders/DetailOrder/DetailOrder' /* webpackChunkName: "DetailOrder" */
  ),
);

const Authorization = lazy(() =>
  import(
    './components/Authorization/Authorization' /* webpackChunkName: "AuthorizationPage" */
  ),
);

const SignInForm = lazy(() =>
  import(
    './components/Authorization/SignIn/SignIn' /* webpackChunkName: "SignInForm" */
  ),
);

const RegistrationForm = lazy(() =>
  import(
    './components/Authorization/Registration/RegistrationForm' /* webpackChunkName: "RegistrationForm" */
  ),
);

function App() {
  return (
    <Suspense fallback={<Loader />}>
      <BrowserRouter>
        <Switch>
          <PrivateRoute exact path={'/'}>
            <Navigation />
          </PrivateRoute>
          <PrivateRoute exact path="/categories">
            <Navigation />
            <Categories />
          </PrivateRoute>
          <PrivateRoute path="/categories/:id">
            <DetailCategory />
          </PrivateRoute>
          <PrivateRoute exact path="/goods">
            <Navigation />
            <Goods />
          </PrivateRoute>
          <PrivateRoute path="/goods/:id">
            <DetailGood />
          </PrivateRoute>
          <PrivateRoute exact path="/orders">
            <Navigation />
            <Orders />
          </PrivateRoute>
          <PrivateRoute path="/orders/:id">
            <DetailOrder />
          </PrivateRoute>
          <PublicRoute path={'/authorization'} restricted>
            <Authorization />
            <PublicRoute exact path={'/authorization/login'} restricted>
              <SignInForm />
            </PublicRoute>
            <PublicRoute exact path={'/authorization/registration'} restricted>
              <RegistrationForm />
            </PublicRoute>
          </PublicRoute>
        </Switch>
        <ToastContainer
          position="top-right"
          autoClose={3000}
          hideProgressBar={false}
          newestOnTop={false}
          closeOnClick
          rtl={false}
          pauseOnFocusLoss
          draggable
          pauseOnHover
        />
      </BrowserRouter>
    </Suspense>
  );
}

export default App;
